@@ -21,3 +21,8 @@ def reindex_searchable_text(context):
     portal_catalog = api.portal.get_tool("portal_catalog")
     portal_catalog.manage_reindexIndex(ids=["SearchableText"])
     logger.info("Reindexed SearchableText index")
+
+
+def upgrade_barceloneta(context):
+    portal_setup = api.portal.get_tool("portal_setup")
+    portal_setup.upgradeProfile("plonetheme.barceloneta:default")
